<?php

namespace App\Core;

use PDO;
use PDOException;

/**
 * Classe singleton pour gérer la connexion à la base de données MySQL.
 */
class Database
{
    private static $instance = null; // Instance unique de la connexion PDO
    private $conn; // L'objet de connexion PDO

    /**
     * Constructeur privé pour empêcher l'instanciation directe (Singleton).
     *
     * @param string $host Nom d'hôte de la base de données
     * @param string $dbName Nom de la base de données
     * @param string $user Nom d'utilisateur de la base de données
     * @param string $password Mot de passe de la base de données
     * @throws PDOException Si la connexion échoue
     */
    private function __construct($host, $dbName, $user, $password)
    {
        $dsn = "mysql:host=$host;dbname=$dbName;charset=utf8mb4";
        $options = [
            PDO::ATTR_ERRMODE            => PDO::ERRMODE_EXCEPTION, // Rapporte les erreurs SQL sous forme d'exceptions
            PDO::ATTR_DEFAULT_FETCH_MODE => PDO::FETCH_ASSOC,     // Récupère les résultats sous forme de tableaux associatifs
            PDO::ATTR_EMULATE_PREPARES   => false,                // Désactive l'émulation des requêtes préparées pour une meilleure sécurité
        ];
        try {
            $this->conn = new PDO($dsn, $user, $password, $options);
        } catch (PDOException $e) {
            // Log l'erreur plutôt que de l'afficher directement en production
            error_log("Erreur de connexion à la base de données: " . $e->getMessage());
            // Relance l'exception après l'avoir logguée
            throw new PDOException("Impossible de se connecter à la base de données.", (int)$e->getCode());
        }
    }

    /**
     * Connecte à la base de données ou retourne l'instance existante.
     *
     * @param string $host Nom d'hôte de la base de données
     * @param string $dbName Nom de la base de données
     * @param string $user Nom d'utilisateur de la base de données
     * @param string $password Mot de passe de la base de données
     */
    public static function connect($host, $dbName, $user, $password)
    {
        if (self::$instance === null) {
            self::$instance = new Database($host, $dbName, $user, $password);
        }
    }

    /**
     * Retourne l'instance PDO de la connexion à la base de données.
     *
     * @return PDO L'objet de connexion PDO
     * @throws \Exception Si la connexion n'a pas été établie au préalable
     */
    public static function getInstance()
    {
        if (self::$instance === null) {
            throw new \Exception("La base de données n'est pas connectée. Appelez Database::connect() d'abord.");
        }
        return self::$instance->conn;
    }
}
